@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
-our $DATE = '2015-10-20'; # DATE
-our $VERSION = '1.36'; # VERSION
+our $DATE = '2015-11-11'; # DATE
+our $VERSION = '1.37'; # VERSION
 
 use 5.010001;
 use strict;
@@ -1399,7 +1399,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{::Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 1.36 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-10-20.
+This document describes version 1.37 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-11-11.
 
 =head1 DESCRIPTION
 
@@ -1665,97 +1665,6 @@ Set to true if user specifies C<--naked-res>.
 
 =back
 
-=head1 CONFIGURATION
-
-Configuration can be used to set function arguments as well as some common
-options.
-
-Configuration is currently in the L<IOD> (basically INI) format.
-
-By default these paths are searched: C<$HOME/.config/$prog_name.conf>,
-C<$HOME/$prog_name.conf>, C</etc/$prog_name.conf>. The location can be
-customized from command-line option C<--config-path>.
-
-All existing configuration files will be read in order, and the result merged if
-more than one files exist.
-
-Section names map to subcommand names. For application that does not have
-subcommand, you can put parameters outside any section, e.g.:
-
- param=val
- otherparam=val
- ...
-
-For application that has subcommands, put parameters inside section with the
-same name as the subcommand name:
-
- [subcommand1]
- param=val
- ...
-
- [subcommand2]
- param2=val
- ...
-
-Or you can also put some parameters outside the section which will be used for
-all subcommands:
-
- commonarg=val
-
- [subcommand1]
- param1=val
- ...
-
- [subcommand2]
- param2=val
- ...
-
-A configuration file can also have (multiple) profiles, to allow multiple
-configuration to be stored in a single file. Section names can have
-"profile=PROFILENAME" suffix to mark it as belonging to a certain profile.
-Parameters in sections with matching "profile=PROFILENAME" will be read.
-Parameters in sections without any profile names will still be read. Example:
-
- a=0
- b=0
- d=9
-
- [profile=p1]
- a=1
- b=2
-
- [profile=p2]
- a=10
- b=20
-
- [subcommand1 profile=p1]
- c=3
-
- [subcommand1 profile=p2]
- c=1
-
-If you run:
-
- % cmd subcommand1
-
-then your subcommand1 function will get: a=0, b=0, d=9.
-
- % cmd subcommand1 --config-profile p1
-
-then your subcommand1 function will get: a=1, b=2, c=3, d=9. If you run:
-
- % cmd subcommand1 --config-profile p2
-
-then your subcommand1 function will get: a=10, b=20, c=30, d=9.
-
-Parameter names map to function argument names or common option. If a common
-option name clashes with a function argument name, the function argument is
-accessible using the C<NAME.arg> syntax. For example, C<log_level> is a common
-option name. If your function also has a C<log_level> argument, to set this
-function argument, you write:
-
- log_level.arg=blah
-
 =head1 ATTRIBUTES
 
 =head2 actions => array
